@@ -1,18 +1,12 @@
-"""
-translator.py
--------------
-
-RSM Translator: take a Manuscript and return a HTML string.
-
-"""
+"""Input: abstract syntax tree -- Output: HTML body."""
 
 import logging
-from typing import Iterable, Callable, Any
-from collections import namedtuple
-from abc import ABC, abstractmethod
-from typing import Iterable
-from icecream import ic
 import textwrap
+from abc import ABC, abstractmethod
+from collections import namedtuple
+from typing import Any, Callable, Iterable, Optional
+
+from icecream import ic
 
 from . import nodes
 
@@ -219,7 +213,7 @@ class AppendNodeTag(AppendOpenTag):
         node: nodes.Node,
         tag: str = "div",
         *,
-        additional_classes: list[str] | None = None,
+        additional_classes: Optional[list[str]] = None,
         newline_inner: bool = True,
         newline_outer: bool = True,
     ):
@@ -381,10 +375,12 @@ class Action(namedtuple("Action", "node action method")):
 
 
 class Translator:
-    """This is an example doctest.
+    """Translate an abstract syntax tree into HTML.
 
     Examples
     --------
+    This is an example doctest.
+
     >>> [1, 2, 3]
     [1, 2, 3]
 
@@ -897,7 +893,7 @@ class Translator:
 
 class HandrailsTranslator(Translator):
     @staticmethod
-    def _make_option_tag(opt):
+    def _make_option_tag(opt: str) -> AppendOpenCloseTag:
         return AppendOpenCloseTag(
             "span",
             opt,
@@ -974,7 +970,7 @@ class HandrailsTranslator(Translator):
         batch = super().visit_abstract(node)
         return self._replace_batch_with_handrails(1, batch)
 
-    def visit_contents(self, node: nodes.Abstract) -> EditCommand:
+    def visit_contents(self, node: nodes.Contents) -> EditCommand:
         batch = super().visit_contents(node)
         return self._replace_batch_with_handrails(0, batch)
 
